@@ -1,11 +1,10 @@
-"""Country."""
-
-# isort: skip_file
+"""i18n."""
 
 # local
 from .es import es_cif, es_doi, es_nie, es_nif
 from .fi import fi_business_id, fi_ssn
 from .fr import fr_department, fr_ssn
+from .ind import ind_aadhar, ind_pan
 
 __all__ = (
     "fi_business_id",
@@ -16,4 +15,6 @@ __all__ = (
     "es_nif",
     "fr_department",
     "fr_ssn",
+    "ind_aadhar",
+    "ind_pan",
 )
